"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const console_logger_1 = require("./../logging/console-logger");
const _1 = require("../");
const hub_1 = require("./hub");
class HubBuilder {
    constructor() {
        this.supportedServers = [];
        this.supportedModules = [];
    }
    static get instance() {
        return this._instance || (this._instance = new HubBuilder());
    }
    withContainer(container) {
        this.container = container;
        return this;
    }
    withLogger(logger) {
        this.logger = logger;
        return this;
    }
    withFramework(tsFramework) {
        this.tsFramework = tsFramework;
        return this;
    }
    withServerSupport(server) {
        this.supportedServers.push(server);
        return this;
    }
    withModule(module) {
        this.supportedModules.push(module);
        return this;
    }
    buildHub() {
        this.initializeContainer()
            .initializeLogger()
            .initializeFramework();
        var hub = new hub_1.Hub(this.supportedServers, this.supportedModules, this.container, this.tsFramework);
        this.reset();
        return hub;
    }
    reset() {
        this.container = null;
        this.logger = null;
        this.supportedServers = [];
        this.tsFramework = null;
    }
    initializeFramework() {
        if (!this.tsFramework) {
            var noFramework = "No framework was configured";
            this.logger.crit(noFramework);
            throw noFramework;
        }
        return this;
    }
    initializeLogger() {
        this.logger = this.logger || new console_logger_1.ConsoleLogger();
        this.container.bind(_1.Types.TsHubLogger).toConstantValue(this.logger);
        return this;
    }
    initializeContainer() {
        this.container = this.container || new _1.InversifyContainer();
        this.container.bind(_1.Types.Container).toConstantValue(this.container);
        return this;
    }
}
exports.HubBuilder = HubBuilder;
//# sourceMappingURL=hub-builder.js.map