"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const types_1 = require("./../container/types");
class Hub {
    constructor(servers, modules, container, tsFramework) {
        this.servers = servers;
        this.modules = modules;
        this.container = container;
        this.tsFramework = tsFramework;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            var controllerBuilders = this.setupDependencies();
            var promises = this.runServers(controllerBuilders);
            return Promise.all(promises);
        });
    }
    setupDependencies() {
        this.servers.forEach(s => s.setupDependencies(this.container));
        this.modules.forEach(m => m.setupModule(this.container, this.servers));
        return this.tsFramework.setupFramework(this.container)
            .loadControllerBuilders(this.container);
    }
    runServers(controllerBuilders) {
        let logger = this.container.get(types_1.Types.TsHubLogger);
        return this.servers.map((server) => {
            controllerBuilders = controllerBuilders.filter((controllerBuilder) => {
                if (controllerBuilder.supportsServer(server)) {
                    let controller = controllerBuilder.buildController();
                    controller.attachToServer(server);
                    return false;
                }
                return true;
            });
            let runServerPromise = server.run();
            runServerPromise.then(() => {
                logger.info(server.getStatus());
            }, () => {
                logger.info(server.getStatus());
            });
            return runServerPromise;
        });
    }
    stop() {
        let logger = this.container.get(types_1.Types.TsHubLogger);
        var promises = this.servers.map((server) => {
            if (server) {
                return Promise.resolve(true);
            }
            let runServerPromise = server.stop();
            runServerPromise.then(() => {
                logger.info(server.getStatus());
            }, () => {
                logger.info(server.getStatus());
            });
            return runServerPromise;
        });
        return Promise.all(promises);
    }
}
exports.Hub = Hub;
//# sourceMappingURL=hub.js.map